@@ -260,12 +260,12 @@ corresponding field data returned (or "I<-na->", if no value).
 
 Returns an array of strings representing all stream URLs found.
 If I<"playlist"> is specified, then an extended m3u playlist is returned 
-instead of stream url(s).  NOTE:  For Apple, Castbox, and Google 
-podcasts, if an author / channel page url is given, rather than an 
-individual podcast episode's url, get() returns the first (latest?) 
-podcast episode found, and get("playlist") returns an extended m3u 
-playlist containing the urls, titles, etc. for all the podcast 
-episodes found on that page url.
+instead of stream url(s).  NOTE:  For Apple, Castbox, Google, Spreaker, 
+and SermonAudio podcasts, if an author / channel page url is given, 
+rather than an individual podcast episode's url, get() returns the 
+first (latest?) podcast episode found, and get("playlist") returns an 
+extended m3u playlist containing the urls, titles, etc. for all the podcast 
+episodes found on that page url from latest to oldest.
 
 =item $station->B<getURL>([I<options>])
 
@@ -485,7 +485,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.72';
+our $VERSION = '1.80';
 our $DEBUG = 0;
 
 require Exporter;
